pytilities.delegation.decorators — Pytilities v1.0.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.delegation »

# pytilities.delegation.decorators

Various decorators to ease delegation

`pytilities.delegation.decorators.` `in_profile`(profile_name='default', modifiers='rwd')

  Includes the decorated attribute in the specified profile.

  Parameters: | profile_name (string) – name of the Profile to add the attribute to modifiers (str combination of r:read, w:write, d:delete (order is not) – the kind of access to allow

  important, but each modifier may appear at most once).

`pytilities.delegation.decorators.` `profile_carrier`(cls=None)

  Sets an attribute_profiles attribute on the class.

  The attribute_profiles attribute is a dict with profiles generated from in_profile annotations found on class attributes. It has profile names of type str as key and the respective profile as value.

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.delegation »